==> openshift-model-monitoring-5.10.1-sources.jar: io/fabric8/openshift/api/model/monitoring/v1/QuerySpecFluentImpl.java <==
package io.fabric8.openshift.api.model.monitoring.v1;

import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class QuerySpecFluentImpl<A extends io.fabric8.openshift.api.model.monitoring.v1.QuerySpecFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.monitoring.v1.QuerySpecFluent<A>{
  public QuerySpecFluentImpl() {
  }
  public QuerySpecFluentImpl(io.fabric8.openshift.api.model.monitoring.v1.QuerySpec instance) {
    this.withLookbackDelta(instance.getLookbackDelta()); 
    this.withMaxConcurrency(instance.getMaxConcurrency()); 
    this.withMaxSamples(instance.getMaxSamples()); 
    this.withTimeout(instance.getTimeout()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String lookbackDelta;
  private java.lang.Integer maxConcurrency;
  private java.lang.Integer maxSamples;
  private java.lang.String timeout;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getLookbackDelta() {
    return this.lookbackDelta;
  }
  public A withLookbackDelta(java.lang.String lookbackDelta) {
    this.lookbackDelta=lookbackDelta; return (A) this;
  }
  public java.lang.Boolean hasLookbackDelta() {
    return this.lookbackDelta != null;
  }
  
  /**
   * Method is deprecated. use withLookbackDelta instead.
   */
  @java.lang.Deprecated
  public A withNewLookbackDelta(java.lang.String arg0) {
    return (A)withLookbackDelta(new String(arg0));
  }
  public java.lang.Integer getMaxConcurrency() {
    return this.maxConcurrency;
  }
  public A withMaxConcurrency(java.lang.Integer maxConcurrency) {
    this.maxConcurrency=maxConcurrency; return (A) this;
  }
  public java.lang.Boolean hasMaxConcurrency() {
    return this.maxConcurrency != null;
  }
  public java.lang.Integer getMaxSamples() {
    return this.maxSamples;
  }
  public A withMaxSamples(java.lang.Integer maxSamples) {
    this.maxSamples=maxSamples; return (A) this;
  }
  public java.lang.Boolean hasMaxSamples() {
    return this.maxSamples != null;
  }
  public java.lang.String getTimeout() {
    return this.timeout;
  }
  public A withTimeout(java.lang.String timeout) {
    this.timeout=timeout; return (A) this;
  }
  public java.lang.Boolean hasTimeout() {
    return this.timeout != null;
  }
  
  /**
   * Method is deprecated. use withTimeout instead.
   */
  @java.lang.Deprecated
  public A withNewTimeout(java.lang.String arg0) {
    return (A)withTimeout(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    QuerySpecFluentImpl that = (QuerySpecFluentImpl) o;
    if (lookbackDelta != null ? !lookbackDelta.equals(that.lookbackDelta) :that.lookbackDelta != null) return false;
    if (maxConcurrency != null ? !maxConcurrency.equals(that.maxConcurrency) :that.maxConcurrency != null) return false;
    if (maxSamples != null ? !maxSamples.equals(that.maxSamples) :that.maxSamples != null) return false;
    if (timeout != null ? !timeout.equals(that.timeout) :that.timeout != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(lookbackDelta,  maxConcurrency,  maxSamples,  timeout,  additionalProperties,  super.hashCode());
  }
  
}

==> openshift-model-monitoring-5.12.1-sources.jar: io/fabric8/openshift/api/model/monitoring/v1/QuerySpecFluentImpl.java <==
package io.fabric8.openshift.api.model.monitoring.v1;

import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class QuerySpecFluentImpl<A extends io.fabric8.openshift.api.model.monitoring.v1.QuerySpecFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.monitoring.v1.QuerySpecFluent<A>{
  public QuerySpecFluentImpl() {
  }
  public QuerySpecFluentImpl(io.fabric8.openshift.api.model.monitoring.v1.QuerySpec instance) {
    this.withLookbackDelta(instance.getLookbackDelta()); 
    this.withMaxConcurrency(instance.getMaxConcurrency()); 
    this.withMaxSamples(instance.getMaxSamples()); 
    this.withTimeout(instance.getTimeout()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String lookbackDelta;
  private java.lang.Integer maxConcurrency;
  private java.lang.Integer maxSamples;
  private java.lang.String timeout;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getLookbackDelta() {
    return this.lookbackDelta;
  }
  public A withLookbackDelta(java.lang.String lookbackDelta) {
    this.lookbackDelta=lookbackDelta; return (A) this;
  }
  public java.lang.Boolean hasLookbackDelta() {
    return this.lookbackDelta != null;
  }
  
  /**
   * Method is deprecated. use withLookbackDelta instead.
   */
  @java.lang.Deprecated
  public A withNewLookbackDelta(java.lang.String arg0) {
    return (A)withLookbackDelta(new String(arg0));
  }
  public java.lang.Integer getMaxConcurrency() {
    return this.maxConcurrency;
  }
  public A withMaxConcurrency(java.lang.Integer maxConcurrency) {
    this.maxConcurrency=maxConcurrency; return (A) this;
  }
  public java.lang.Boolean hasMaxConcurrency() {
    return this.maxConcurrency != null;
  }
  public java.lang.Integer getMaxSamples() {
    return this.maxSamples;
  }
  public A withMaxSamples(java.lang.Integer maxSamples) {
    this.maxSamples=maxSamples; return (A) this;
  }
  public java.lang.Boolean hasMaxSamples() {
    return this.maxSamples != null;
  }
  public java.lang.String getTimeout() {
    return this.timeout;
  }
  public A withTimeout(java.lang.String timeout) {
    this.timeout=timeout; return (A) this;
  }
  public java.lang.Boolean hasTimeout() {
    return this.timeout != null;
  }
  
  /**
   * Method is deprecated. use withTimeout instead.
   */
  @java.lang.Deprecated
  public A withNewTimeout(java.lang.String arg0) {
    return (A)withTimeout(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    QuerySpecFluentImpl that = (QuerySpecFluentImpl) o;
    if (lookbackDelta != null ? !lookbackDelta.equals(that.lookbackDelta) :that.lookbackDelta != null) return false;
    if (maxConcurrency != null ? !maxConcurrency.equals(that.maxConcurrency) :that.maxConcurrency != null) return false;
    if (maxSamples != null ? !maxSamples.equals(that.maxSamples) :that.maxSamples != null) return false;
    if (timeout != null ? !timeout.equals(that.timeout) :that.timeout != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(lookbackDelta,  maxConcurrency,  maxSamples,  timeout,  additionalProperties,  super.hashCode());
  }
  
}
